/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994 
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the default keycodes of the Tektroknix X terminal
 * with a Sun4-style keyboard.  
 * By Robert Zwickenpflug <zpg@mmk.e-technik.tu-muenchen.de>
 */

static const KeyCode teksun4_codes [] = {

  /* Row 0 */
  10, 16,
  15, 23, 31, 39, 47, 55, 63, 71, 79, 87, 94, 102, 89, 100,
  95, 103, 101, 126,
  
  /* Row 1 */
  11, 48,
  22, 30, 38, 46, 45, 54, 62, 69, 70, 78, 77, 86, 93, 131,
  111, 127, 134, 12,
  
  /* Row 2 */
  9, 80,
  21, 29, 37, 44, 53, 52, 61, 68, 75, 76, 85, 92, 99,
  98,
  116, 125, 133, 132,

  /* Row 3 */
  13, 112,
  28, 36, 35, 43, 51, 60, 59, 67, 74, 83, 84, 90, 110,
  115, 123, 124,
  
  /* Row 4 */
  14, 17,
  26, 34, 42, 41, 50, 58, 57, 66, 73, 81, 82, 27, 97,
  113, 122, 130, 129,
  
  /* Row 5 */
  24,
  25, 96, 33, 49, 65, 40, 56,
  120, 121
};
